# dash-grid-layout

A draggable and resizable grid layout with responsive breakpoints, for Dash.

(A dash port of [react-grid-layout](https://github.com/react-grid-layout/react-grid-layout))

![dash-grid-layout](./demo.gif)